ButtonSizeVariant enum

Defines size variants for Material 3 Expressive button components.

Each size variant represents a named visual scale. For example, a Material 3 Expressive IconButton uses this value to choose its container size, icon size, and padding.

Inheritance
Available extensions

Values

xSmall → const ButtonSizeVariant

The smallest button size.

small → const ButtonSizeVariant

A small button size.

medium → const ButtonSizeVariant

A medium button size.

large → const ButtonSizeVariant

A large button size.

xLarge → const ButtonSizeVariant

The largest button size.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ButtonSizeVariant>
A constant List of the values in this enum, in order of their declaration.